@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef CALENDARSUPPORT_MESSAGEWIDGET_H
-#define CALENDARSUPPORT_MESSAGEWIDGET_H
+#pragma once
 
 #include "calendarsupport_export.h"
 
@@ -31,4 +30,3 @@ public:
 };
 }
 
-#endif
